@@ -150,7 +150,7 @@ class BuildEnvironment:
     def update_local_requirements(self, requirements: Sequence[LocalRequirement]) -> None:
         """Used to update local requirements. Does not change the stored environment hash."""
 
-        command = self._get_pip_command() + [str(self._project_path / x.path) for x in requirements]
+        command = self._get_pip_command() + [str((self._project_path / x.path).absolute()) for x in requirements]
         logger.info("%s", command)
         with self._open_logfile_and_print_delta_on_error() as fp:
             sp.check_call(command, stdout=fp, stderr=sp.STDOUT)
